==> mars-0.9.2.tar.gz: mars-0.9.2/include/host/mars/mars.h <==
/*
 * Copyright 2008 Sony Corporation of America
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this Library and associated documentation files (the
 * "Library"), to deal in the Library without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Library, and to
 * permit persons to whom the Library is furnished to do so, subject to
 * the following conditions:
 *
 *  The above copyright notice and this permission notice shall be
 *  included in all copies or substantial portions of the Library.
 *
 *  If you modify the Library, you may copy and distribute your modified
 *  version of the Library in object code or as an executable provided
 *  that you also do one of the following:
 *
 *   Accompany the modified version of the Library with the complete
 *   corresponding machine-readable source code for the modified version
 *   of the Library; or,
 *
 *   Accompany the modified version of the Library with a written offer
 *   for a complete machine-readable copy of the corresponding source
 *   code of the modified version of the Library.
 *
 *
 * THE LIBRARY IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * LIBRARY OR THE USE OR OTHER DEALINGS IN THE LIBRARY.
 */

#ifndef MARS_H
#define MARS_H

/**
 * \file
 * \ingroup group_mars_context
 * \brief [host] MARS API
 */

#if defined(__cplusplus)
extern "C" {
#endif

#include <pthread.h>
#include "mars/mars_error.h"
#include "mars/mars_mutex.h"
#include "mars/mars_task.h"

/**
 * \ingroup group_mars_context
 * \brief MARS params structure
 *
 * This structure is initialized by the user and passed into
 * \ref mars_initialize for MARS context initialization.
 */
struct mars_params {
	/** number of mpus utilized by each MARS context
	 * [between 0 and maximum available physical MPUs]
	 */
	unsigned int num_mpus;
};

/**
 * \ingroup group_mars_context
 * \brief MARS context structure
 *
 * An instance of this structure must be created and initialized before
 * using any of the MARS API.
 */
struct mars_context {
	/* parameters for the MARS context */
	struct mars_params *params;
	/* parameters for the MARS kernel */
	struct mars_kernel_params *kernel_params;
	/* process queue where process requests are added */
	struct mars_workload_queue *workload_queue;
	/* array of mpu context threads */
	pthread_t *mpu_context_threads;
	/* num of mpu context threads */
	unsigned int mpu_context_count;
};

/**
 * \ingroup group_mars_context
 * \brief [host] Initializes a single MARS context.
 *
 * This function initializes a single MARS context. A MARS context must be
 * initialized before any of the MARS functionality can be used. This will
 * create the MPU contexts that are each loaded with and run the MARS kernel.
 * The MARS kernel on each MPU will continue to run until the MARS context
 * is finalized through \ref mars_finalize.
 *
 * \note If there are multiple MARS contexts initialized in the system, then
 * each MARS context will suffer the large over head of MPU context switches.
 *
 * \param[out] ctx		- address of context instance to initialize
 * \param[in] params		- pointer to MARS parameters structure
 * \return
 *	MARS_SUCCESS		- successfully initialized MARS context
 * \n	MARS_ERROR_NULL		- null pointer specified
 * \n	MARS_ERROR_PARAMS	- bad MARS params specified
 * \n	MARS_ERROR_MEMORY	- not enough memory
 * \n	MARS_ERROR_INTERNAL	- some internal error occurred
 */
int mars_initialize(struct mars_context *ctx, struct mars_params *params);

/**
 * \ingroup group_mars_context
 * \brief [host] Finalizes a single MARS context.
 *
 * This function finalizes a single MARS context that was previously
 * initialized by \ref mars_initialize. In order to successfully finalize
 * a MARS context, all workloads added to the workload queue must be
 * completed and finalized so that the workload queue is empty.
 *
 * \param[in] ctx		- address of context instance to finalize
 * \return
 *	MARS_SUCCESS		- successfully finalized MARS context
 * \n	MARS_ERROR_NULL		- null pointer specified
 * \n	MARS_ERROR_STATE	- workload queue is not empty
 */
int mars_finalize(struct mars_context *ctx);

#if defined(__cplusplus)
}
#endif

#endif

==> mars-08.06.26.tar.gz: mars-08.06.26/include/host/mars/mars.h <==
/*
 * Copyright 2008 Sony Corporation of America
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this Library and associated documentation files (the
 * "Library"), to deal in the Library without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Library, and to
 * permit persons to whom the Library is furnished to do so, subject to
 * the following conditions:
 *
 *  The above copyright notice and this permission notice shall be 
 *  included in all copies or substantial portions of the Library.
 *
 *  If you modify the Library, you may copy and distribute your modified 
 *  version of the Library in object code or as an executable provided 
 *  that you also do one of the following:
 *
 *   Accompany the modified version of the Library with the complete 
 *   corresponding machine-readable source code for the modified version 
 *   of the Library; or,
 *
 *   Accompany the modified version of the Library with a written offer 
 *   for a complete machine-readable copy of the corresponding source 
 *   code of the modified version of the Library.
 *
 *
 * THE LIBRARY IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * LIBRARY OR THE USE OR OTHER DEALINGS IN THE LIBRARY.
 */

#ifndef MARS_H
#define MARS_H

/**
 * \file
 * \ingroup group_mars_context
 * \brief [host] MARS API
 */

#if defined(__cplusplus)
extern "C" {
#endif

#include <pthread.h>
#include "mars/mars_error.h"
#include "mars/mars_mutex.h"
#include "mars/mars_task.h"

/**
 * \ingroup group_mars_context
 * \brief MARS params structure
 *
 * This structure is initialized by the user and passed into
 * \ref mars_initialize for MARS context initialization.
 */
struct mars_params {
	/** number of mpus utilized by each MARS context
	 * [between 0 and maximum available physical MPUs]
	 */
	unsigned int num_mpus;
};

/**
 * \ingroup group_mars_context
 * \brief MARS context structure
 *
 * An instance of this structure must be created and initialized before
 * using any of the MARS API.
 */
struct mars_context {
	/* parameters for the MARS context */
	struct mars_params *params;
	/* parameters for the MARS kernel */
	struct mars_kernel_params *kernel_params;
	/* mutex for the MARS context */
	struct mars_mutex *mutex;
	/* process queue where process requests are added */
	struct mars_workload_queue *workload_queue;
	/* array of spu context threads */
	pthread_t *mpu_context_threads;
	/* num of mpu context threads */
	unsigned int mpu_context_count;
};

/**
 * \ingroup group_mars_context
 * \brief [host] Initializes a single MARS context.
 *
 * This function initializes a single MARS context. A MARS context must be
 * initialized before any of the MARS functionality can be used. This will
 * create the MPU contexts that are each loaded with and run the MARS kernel.
 * The MARS kernel on each MPU will continue to run until the MARS context
 * is finalized through \ref mars_finalize.
 *
 * \note If there are multiple MARS contexts initialized in the system, then
 * each MARS context will suffer the large over head of MPU context switches.
 *
 * \param[out] ctx		- address of context instance to initialize
 * \param[in] params		- pointer to MARS parameters structure
 * \return
 *	MARS_SUCCESS		- successfully initialized MARS context
 * \n	MARS_ERROR_NULL		- null pointer specified
 * \n	MARS_ERROR_PARAMS	- bad MARS params specified
 * \n	MARS_ERROR_MEMORY	- not enough memory
 * \n	MARS_ERROR_INTERNAL	- some internal error occurred
 */
int mars_initialize(struct mars_context *ctx, struct mars_params *params);

/**
 * \ingroup group_mars_context
 * \brief [host] Finalizes a single MARS context.
 *
 * This function finalizes a single MARS context that was previously
 * initialized by \ref mars_initialize. In order to successfully finalize
 * a MARS context, all workloads added to the workload queue must be
 * completed and finalized so that the workload queue is empty.
 *
 * \param[in] ctx		- address of context instance to finalize
 * \return
 *	MARS_SUCCESS		- successfully finalized MARS context
 * \n	MARS_ERROR_NULL		- null pointer specified
 * \n	MARS_ERROR_STATE	- workload queue is not empty
 */
int mars_finalize(struct mars_context *ctx);

#if defined(__cplusplus)
}
#endif

#endif
